==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/event/observer/priority/MoonObservers.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2015, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.event.observer.priority;

import javax.annotation.Priority;
import javax.enterprise.event.Observes;
import javax.interceptor.Interceptor;

import org.jboss.cdi.tck.util.ActionSequence;

public class MoonObservers {

    public static class Observer1 {
        public void observeMoon(@Observes @Priority(Interceptor.Priority.APPLICATION) MoonActivity moonActivity) {
            ActionSequence.addAction(getClass().getName());
        }
    }

    public static class Observer2 {
        public void observeMoon(@Observes Moonrise moonrise) {
            ActionSequence.addAction(getClass().getName());
        }
    }

    public static class Observer3 {
        public void observeMoon(@Observes @Priority(Interceptor.Priority.APPLICATION + 900) MoonActivity moonActivity) {
            ActionSequence.addAction(getClass().getName());
        }
    }

    public static class Observer4 {
        public void observeMoon(@Observes @Priority(Interceptor.Priority.APPLICATION + 950) Moonrise moonrise) {
            ActionSequence.addAction(getClass().getName());
        }
    }

}

==> cdi-tck-3.0.3-dist.zip: org/jboss/cdi/tck/tests/event/observer/priority/MoonObservers.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2015, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.event.observer.priority;

import jakarta.annotation.Priority;
import jakarta.enterprise.event.Observes;
import jakarta.interceptor.Interceptor;

import org.jboss.cdi.tck.util.ActionSequence;

public class MoonObservers {

    public static class Observer1 {
        public void observeMoon(@Observes @Priority(Interceptor.Priority.APPLICATION) MoonActivity moonActivity) {
            ActionSequence.addAction(getClass().getName());
        }
    }

    public static class Observer2 {
        public void observeMoon(@Observes Moonrise moonrise) {
            ActionSequence.addAction(getClass().getName());
        }
    }

    public static class Observer3 {
        public void observeMoon(@Observes @Priority(Interceptor.Priority.APPLICATION + 900) MoonActivity moonActivity) {
            ActionSequence.addAction(getClass().getName());
        }
    }

    public static class Observer4 {
        public void observeMoon(@Observes @Priority(Interceptor.Priority.APPLICATION + 950) Moonrise moonrise) {
            ActionSequence.addAction(getClass().getName());
        }
    }

}
